You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@trafodion.apache.org by an...@apache.org on 2017/09/07 01:55:11 UTC

[17/30] incubator-trafodion git commit: TRAFODION-2731 CodeCleanup: Remove obsolete, legacy and unused code

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/executor/ExExeUtil.h
----------------------------------------------------------------------
diff --git a/core/sql/executor/ExExeUtil.h b/core/sql/executor/ExExeUtil.h
index 07d3b22..76ccfe2 100644
--- a/core/sql/executor/ExExeUtil.h
+++ b/core/sql/executor/ExExeUtil.h
@@ -109,16 +109,16 @@ class ExExeUtilTdb : public ComTdbExeUtil
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExExeUtilTdb()
+  ExExeUtilTdb()
     {}
 
-  NA_EIDPROC virtual ~ExExeUtilTdb()
+  virtual ~ExExeUtilTdb()
     {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
  private:
   // ---------------------------------------------------------------------
@@ -419,8 +419,7 @@ private:
 
   NABoolean restoreTimeout_;
 
-  AnsiOrNskName *extractedPartsObj_;
-
+  AnsiName *extractedPartsObj_;
 
   Int64 startTime_;
   Int64 endTime_;
@@ -463,16 +462,16 @@ class ExExeUtilDisplayExplainTdb : public ComTdbExeUtilDisplayExplain
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExExeUtilDisplayExplainTdb()
+  ExExeUtilDisplayExplainTdb()
     {}
 
-  NA_EIDPROC virtual ~ExExeUtilDisplayExplainTdb()
+  virtual ~ExExeUtilDisplayExplainTdb()
     {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
  private:
   // ---------------------------------------------------------------------
@@ -521,7 +520,7 @@ class ExExeUtilDisplayExplainTcb : public ExExeUtilTcb
 
   virtual short work();
 
-  NA_EIDPROC virtual ex_tcb_private_state * allocatePstates(
+  virtual ex_tcb_private_state * allocatePstates(
                                                             Lng32 &numElems,      // inout, desired/actual elements
                                                             Lng32 &pstateLength); // out, length of one element
 
@@ -669,16 +668,16 @@ class ExExeUtilDisplayExplainComplexTdb : public ComTdbExeUtilDisplayExplainComp
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExExeUtilDisplayExplainComplexTdb()
+  ExExeUtilDisplayExplainComplexTdb()
     {}
 
-  NA_EIDPROC virtual ~ExExeUtilDisplayExplainComplexTdb()
+  virtual ~ExExeUtilDisplayExplainComplexTdb()
     {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
  private:
   // ---------------------------------------------------------------------
@@ -727,7 +726,7 @@ class ExExeUtilDisplayExplainComplexTcb : public ExExeUtilTcb
 
   virtual short work();
 
-  NA_EIDPROC virtual ex_tcb_private_state *
+  virtual ex_tcb_private_state *
   allocatePstates(
        Lng32 &numElems,      // inout, desired/actual elements
        Lng32 &pstateLength); // out, length of one element
@@ -784,7 +783,7 @@ class ExExeUtilDisplayExplainShowddlTcb : public ExExeUtilTcb
 
   virtual short work();
 
-  NA_EIDPROC virtual ex_tcb_private_state *
+  virtual ex_tcb_private_state *
   allocatePstates(
        Lng32 &numElems,      // inout, desired/actual elements
        Lng32 &pstateLength); // out, length of one element
@@ -833,16 +832,16 @@ class ExExeUtilCreateTableAsTdb : public ComTdbExeUtilCreateTableAs
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExExeUtilCreateTableAsTdb()
+  ExExeUtilCreateTableAsTdb()
     {}
 
-  NA_EIDPROC virtual ~ExExeUtilCreateTableAsTdb()
+  virtual ~ExExeUtilCreateTableAsTdb()
     {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
  private:
   // ---------------------------------------------------------------------
@@ -889,7 +888,7 @@ class ExExeUtilCreateTableAsTcb : public ExExeUtilTcb
       return (ExExeUtilCreateTableAsTdb &) tdb;
     };
 
-  NA_EIDPROC virtual ex_tcb_private_state * allocatePstates(
+  virtual ex_tcb_private_state * allocatePstates(
        Lng32 &numElems,      // inout, desired/actual elements
        Lng32 &pstateLength); // out, length of one element
 
@@ -944,16 +943,16 @@ class ExExeUtilCleanupVolatileTablesTdb : public ComTdbExeUtilCleanupVolatileTab
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExExeUtilCleanupVolatileTablesTdb()
+  ExExeUtilCleanupVolatileTablesTdb()
     {}
 
-  NA_EIDPROC virtual ~ExExeUtilCleanupVolatileTablesTdb()
+  virtual ~ExExeUtilCleanupVolatileTablesTdb()
     {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
  private:
   // ---------------------------------------------------------------------
@@ -1074,16 +1073,16 @@ class ExExeUtilGetVolatileInfoTdb : public ComTdbExeUtilGetVolatileInfo
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExExeUtilGetVolatileInfoTdb()
+  ExExeUtilGetVolatileInfoTdb()
     {}
 
-  NA_EIDPROC virtual ~ExExeUtilGetVolatileInfoTdb()
+  virtual ~ExExeUtilGetVolatileInfoTdb()
     {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
  private:
   // ---------------------------------------------------------------------
@@ -1169,16 +1168,16 @@ class ExExeUtilGetErrorInfoTdb : public ComTdbExeUtilGetErrorInfo
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExExeUtilGetErrorInfoTdb()
+  ExExeUtilGetErrorInfoTdb()
     {}
 
-  NA_EIDPROC virtual ~ExExeUtilGetErrorInfoTdb()
+  virtual ~ExExeUtilGetErrorInfoTdb()
     {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
  private:
   // ---------------------------------------------------------------------
@@ -1272,16 +1271,16 @@ class ExExeUtilLoadVolatileTableTdb : public ComTdbExeUtilLoadVolatileTable
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExExeUtilLoadVolatileTableTdb()
+  ExExeUtilLoadVolatileTableTdb()
     {}
 
-  NA_EIDPROC virtual ~ExExeUtilLoadVolatileTableTdb()
+  virtual ~ExExeUtilLoadVolatileTableTdb()
     {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
  private:
   // ---------------------------------------------------------------------
@@ -1369,16 +1368,16 @@ class ExExeUtilFastDeleteTdb : public ComTdbExeUtilFastDelete
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExExeUtilFastDeleteTdb()
+  ExExeUtilFastDeleteTdb()
     {}
 
-  NA_EIDPROC virtual ~ExExeUtilFastDeleteTdb()
+  virtual ~ExExeUtilFastDeleteTdb()
     {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
  private:
   // ---------------------------------------------------------------------
@@ -1422,7 +1421,7 @@ class ExExeUtilFastDeleteTcb : public ExExeUtilTcb
 
   virtual short work();
 
-  NA_EIDPROC virtual ex_tcb_private_state * allocatePstates(
+  virtual ex_tcb_private_state * allocatePstates(
                                                             Lng32 &numElems,      // inout, desired/actual elements
                                                             Lng32 &pstateLength); // out, length of one element
 
@@ -1505,16 +1504,16 @@ public:
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExExeUtilGetStatisticsTdb()
+  ExExeUtilGetStatisticsTdb()
   {}
 
-  NA_EIDPROC virtual ~ExExeUtilGetStatisticsTdb()
+  virtual ~ExExeUtilGetStatisticsTdb()
   {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
 private:
   // ---------------------------------------------------------------------
@@ -1563,7 +1562,7 @@ public:
 
   virtual short work();
 
-  NA_EIDPROC virtual ex_tcb_private_state * allocatePstates(
+  virtual ex_tcb_private_state * allocatePstates(
        Lng32 &numElems,      // inout, desired/actual elements
        Lng32 &pstateLength); // out, length of one element
 
@@ -1635,16 +1634,16 @@ public:
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExExeUtilGetProcessStatisticsTdb()
+  ExExeUtilGetProcessStatisticsTdb()
   {}
 
-  NA_EIDPROC virtual ~ExExeUtilGetProcessStatisticsTdb()
+  virtual ~ExExeUtilGetProcessStatisticsTdb()
   {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
 private:
 };
@@ -1663,16 +1662,16 @@ public:
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExExeUtilGetUIDTdb()
+  ExExeUtilGetUIDTdb()
   {}
 
-  NA_EIDPROC virtual ~ExExeUtilGetUIDTdb()
+  virtual ~ExExeUtilGetUIDTdb()
   {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
 private:
   // ---------------------------------------------------------------------
@@ -1720,7 +1719,7 @@ public:
 
   virtual short work();
 
-  NA_EIDPROC virtual ex_tcb_private_state * allocatePstates(
+  virtual ex_tcb_private_state * allocatePstates(
        Lng32 &numElems,      // inout, desired/actual elements
        Lng32 &pstateLength); // out, length of one element
 
@@ -1764,16 +1763,16 @@ public:
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExExeUtilGetQIDTdb()
+  ExExeUtilGetQIDTdb()
   {}
 
-  NA_EIDPROC virtual ~ExExeUtilGetQIDTdb()
+  virtual ~ExExeUtilGetQIDTdb()
   {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
 private:
   // ---------------------------------------------------------------------
@@ -1821,7 +1820,7 @@ public:
 
   virtual short work();
 
-  NA_EIDPROC virtual ex_tcb_private_state * allocatePstates(
+  virtual ex_tcb_private_state * allocatePstates(
        Lng32 &numElems,      // inout, desired/actual elements
        Lng32 &pstateLength); // out, length of one element
 
@@ -1865,16 +1864,16 @@ public:
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExExeUtilPopulateInMemStatsTdb()
+  ExExeUtilPopulateInMemStatsTdb()
   {}
 
-  NA_EIDPROC virtual ~ExExeUtilPopulateInMemStatsTdb()
+  virtual ~ExExeUtilPopulateInMemStatsTdb()
   {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
 private:
   // ---------------------------------------------------------------------
@@ -1922,7 +1921,7 @@ public:
 
   virtual short work();
 
-  NA_EIDPROC virtual ex_tcb_private_state * allocatePstates(
+  virtual ex_tcb_private_state * allocatePstates(
        Lng32 &numElems,      // inout, desired/actual elements
        Lng32 &pstateLength); // out, length of one element
 
@@ -1972,16 +1971,16 @@ public:
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExExeUtilAqrWnrInsertTdb()
+  ExExeUtilAqrWnrInsertTdb()
   {}
 
-  NA_EIDPROC virtual ~ExExeUtilAqrWnrInsertTdb()
+  virtual ~ExExeUtilAqrWnrInsertTdb()
   {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
 private:
   // ---------------------------------------------------------------------
@@ -2067,16 +2066,16 @@ public:
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExExeUtilLongRunningTdb()
+  ExExeUtilLongRunningTdb()
   {}
 
-  NA_EIDPROC virtual ~ExExeUtilLongRunningTdb()
+  virtual ~ExExeUtilLongRunningTdb()
   {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
 private:
   // ---------------------------------------------------------------------
@@ -2123,7 +2122,7 @@ public:
 
   virtual short work();
 
-  NA_EIDPROC virtual ex_tcb_private_state * allocatePstates(
+  virtual ex_tcb_private_state * allocatePstates(
        Lng32 &numElems,      // inout, desired/actual elements
        Lng32 &pstateLength); // out, length of one element
 
@@ -2208,7 +2207,7 @@ public:
 
   virtual short work();
 
-  NA_EIDPROC virtual ex_tcb_private_state * allocatePstates(
+  virtual ex_tcb_private_state * allocatePstates(
        Lng32 &numElems,      // inout, desired/actual elements
        Lng32 &pstateLength); // out, length of one element
 
@@ -2349,16 +2348,16 @@ public:
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExExeUtilGetMetadataInfoTdb()
+  ExExeUtilGetMetadataInfoTdb()
   {}
 
-  NA_EIDPROC virtual ~ExExeUtilGetMetadataInfoTdb()
+  virtual ~ExExeUtilGetMetadataInfoTdb()
   {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
 private:
   // ---------------------------------------------------------------------
@@ -2406,7 +2405,7 @@ public:
 
   virtual short work();
 
-  NA_EIDPROC virtual ex_tcb_private_state * allocatePstates(
+  virtual ex_tcb_private_state * allocatePstates(
        Lng32 &numElems,      // inout, desired/actual elements
        Lng32 &pstateLength); // out, length of one element
 
@@ -2601,16 +2600,16 @@ public:
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExExeUtilGetHiveMetadataInfoTdb()
+  ExExeUtilGetHiveMetadataInfoTdb()
   {}
 
-  NA_EIDPROC virtual ~ExExeUtilGetHiveMetadataInfoTdb()
+  virtual ~ExExeUtilGetHiveMetadataInfoTdb()
   {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
 private:
   // ---------------------------------------------------------------------
@@ -2701,16 +2700,16 @@ class ExExeUtilShowSetTdb : public ComTdbExeUtilShowSet
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExExeUtilShowSetTdb()
+  ExExeUtilShowSetTdb()
     {}
 
-  NA_EIDPROC virtual ~ExExeUtilShowSetTdb()
+  virtual ~ExExeUtilShowSetTdb()
     {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
  private:
   // ---------------------------------------------------------------------
@@ -2788,16 +2787,16 @@ class ExExeUtilAQRTdb : public ComTdbExeUtilAQR
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExExeUtilAQRTdb()
+  ExExeUtilAQRTdb()
     {}
 
-  NA_EIDPROC virtual ~ExExeUtilAQRTdb()
+  virtual ~ExExeUtilAQRTdb()
     {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
  private:
   // ---------------------------------------------------------------------
@@ -2876,16 +2875,16 @@ class ExExeUtilLobExtractTdb : public ComTdbExeUtilLobExtract
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExExeUtilLobExtractTdb()
+  ExExeUtilLobExtractTdb()
     {}
 
-  NA_EIDPROC virtual ~ExExeUtilLobExtractTdb()
+  virtual ~ExExeUtilLobExtractTdb()
     {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
  private:
   // ---------------------------------------------------------------------
@@ -3006,17 +3005,17 @@ class ExExeUtilLobUpdateTdb : public ComTdbExeUtilLobUpdate
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExExeUtilLobUpdateTdb()
+  ExExeUtilLobUpdateTdb()
     {}
 
-  NA_EIDPROC virtual ~ExExeUtilLobUpdateTdb()
+  virtual ~ExExeUtilLobUpdateTdb()
     {}
 
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 private:
 };
 
@@ -3135,16 +3134,16 @@ class ExExeUtilLobShowddlTdb : public ComTdbExeUtilLobShowddl
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExExeUtilLobShowddlTdb()
+  ExExeUtilLobShowddlTdb()
     {}
 
-  NA_EIDPROC virtual ~ExExeUtilLobShowddlTdb()
+  virtual ~ExExeUtilLobShowddlTdb()
     {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
  private:
   // ---------------------------------------------------------------------
@@ -3278,16 +3277,16 @@ public:
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExExeUtilHiveMDaccessTdb()
+  ExExeUtilHiveMDaccessTdb()
   {}
 
-  NA_EIDPROC virtual ~ExExeUtilHiveMDaccessTdb()
+  virtual ~ExExeUtilHiveMDaccessTdb()
   {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
 private:
   // ---------------------------------------------------------------------
@@ -3340,7 +3339,7 @@ public:
     return (ExExeUtilHiveMDaccessTdb &) tdb;
   };
 
-NA_EIDPROC virtual ex_tcb_private_state *
+virtual ex_tcb_private_state *
   allocatePstates(
        Lng32 &numElems,      // inout, desired/actual elements
        Lng32 &pstateLength); // out, length of one element
@@ -3412,16 +3411,16 @@ class ExExeUtilHiveTruncateTdb : public ComTdbExeUtilHiveTruncate
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExExeUtilHiveTruncateTdb()
+  ExExeUtilHiveTruncateTdb()
     {}
 
-  NA_EIDPROC virtual ~ExExeUtilHiveTruncateTdb()
+  virtual ~ExExeUtilHiveTruncateTdb()
     {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
  private:
   // ---------------------------------------------------------------------
@@ -3466,7 +3465,7 @@ class ExExeUtilHiveTruncateTcb : public ExExeUtilTcb
   virtual void freeResources();
   virtual short work();
 
-  NA_EIDPROC virtual ex_tcb_private_state * allocatePstates(
+  virtual ex_tcb_private_state * allocatePstates(
                                                             Lng32 &numElems,      // inout, desired/actual elements
                                                             Lng32 &pstateLength); // out, length of one element
   virtual Int32 fixup();
@@ -3513,16 +3512,16 @@ class ExExeUtilHiveQueryTdb : public ComTdbExeUtilHiveQuery
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExExeUtilHiveQueryTdb()
+  ExExeUtilHiveQueryTdb()
     {}
 
-  NA_EIDPROC virtual ~ExExeUtilHiveQueryTdb()
+  virtual ~ExExeUtilHiveQueryTdb()
     {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
  private:
   // ---------------------------------------------------------------------
@@ -3608,16 +3607,16 @@ class ExExeUtilHBaseBulkLoadTdb : public ComTdbExeUtilHBaseBulkLoad
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExExeUtilHBaseBulkLoadTdb()
+  ExExeUtilHBaseBulkLoadTdb()
     {}
 
-  NA_EIDPROC virtual ~ExExeUtilHBaseBulkLoadTdb()
+  virtual ~ExExeUtilHBaseBulkLoadTdb()
     {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
  private:
   // ---------------------------------------------------------------------
@@ -3678,7 +3677,7 @@ class ExExeUtilHBaseBulkLoadTcb : public ExExeUtilTcb
                                        short * rc,
                                        int bufPos = 0,
                                        NABoolean   withtime = FALSE);
-  NA_EIDPROC virtual ex_tcb_private_state * allocatePstates(
+  virtual ex_tcb_private_state * allocatePstates(
        Lng32 &numElems,      // inout, desired/actual elements
        Lng32 &pstateLength); // out, length of one element
   void setLoggingLocation();
@@ -3748,16 +3747,16 @@ class ExExeUtilHBaseBulkUnLoadTdb : public ComTdbExeUtilHBaseBulkUnLoad
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExExeUtilHBaseBulkUnLoadTdb()
+  ExExeUtilHBaseBulkUnLoadTdb()
     {}
 
-  NA_EIDPROC virtual ~ExExeUtilHBaseBulkUnLoadTdb()
+  virtual ~ExExeUtilHBaseBulkUnLoadTdb()
     {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
  private:
   // ---------------------------------------------------------------------
@@ -3819,7 +3818,7 @@ class ExExeUtilHBaseBulkUnLoadTcb : public ExExeUtilTcb
                                        short * rc,
                                        int bufPos = 0,
                                        NABoolean   withtime = FALSE);
-  NA_EIDPROC virtual ex_tcb_private_state * allocatePstates(
+  virtual ex_tcb_private_state * allocatePstates(
        Lng32 &numElems,      // inout, desired/actual elements
        Lng32 &pstateLength); // out, length of one element
 
@@ -3919,16 +3918,16 @@ public:
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExExeUtilRegionStatsTdb()
+  ExExeUtilRegionStatsTdb()
   {}
 
-  NA_EIDPROC virtual ~ExExeUtilRegionStatsTdb()
+  virtual ~ExExeUtilRegionStatsTdb()
   {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
 private:
   // ---------------------------------------------------------------------
@@ -4132,16 +4131,16 @@ public:
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExExeUtilLobInfoTdb()
+  ExExeUtilLobInfoTdb()
   {}
 
-  NA_EIDPROC virtual ~ExExeUtilLobInfoTdb()
+  virtual ~ExExeUtilLobInfoTdb()
   {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
 private:
   // ---------------------------------------------------------------------

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/executor/ExExeUtilCommon.cpp
----------------------------------------------------------------------
diff --git a/core/sql/executor/ExExeUtilGetStats.cpp b/core/sql/executor/ExExeUtilGetStats.cpp
index 847985e..1dd0d44 100644
--- a/core/sql/executor/ExExeUtilGetStats.cpp
+++ b/core/sql/executor/ExExeUtilGetStats.cpp
@@ -949,8 +949,7 @@ short ExExeUtilGetStatisticsTcb::work()
 		break;
 	      }
 
-	    if ((statsMergeType_ == SQLCLIDEV_MEASURE_STATS) ||
-		(statsMergeType_ == SQLCLIDEV_ACCUMULATED_STATS) ||
+            if ((statsMergeType_ == SQLCLIDEV_ACCUMULATED_STATS) ||
 		(statsMergeType_ == SQLCLIDEV_PERTABLE_STATS) ||
                 (statsMergeType_ == SQLCLI_PROGRESS_STATS))
 	      {
@@ -1058,9 +1057,7 @@ short ExExeUtilGetStatisticsTcb::work()
 	    if ((NOT getStatsTdb().oldFormat()) &&
 		(NOT getStatsTdb().shortFormat()))
 	      {
-		if (statsMergeType_ == SQLCLIDEV_MEASURE_STATS)
-		  strcpy(statsType, "MEASURE");
-		else if (statsMergeType_ == SQLCLIDEV_ACCUMULATED_STATS)
+		if (statsMergeType_ == SQLCLIDEV_ACCUMULATED_STATS)
 		  strcpy(statsType, "ACCUMULATED");
 		else if (statsMergeType_ == SQLCLIDEV_PERTABLE_STATS)
 		  strcpy(statsType, "PERTABLE");

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/executor/ExExplain.cpp
----------------------------------------------------------------------
diff --git a/core/sql/executor/ExExplain.cpp b/core/sql/executor/ExExplain.cpp
index cb29821..fb7d4f0 100644
--- a/core/sql/executor/ExExplain.cpp
+++ b/core/sql/executor/ExExplain.cpp
@@ -264,15 +264,6 @@ ExExplainTcb::loadModule()
 		       );
 #pragma warn(1506)  // warning elimination 
       //moduleId.module_name = modName_;
-
-      // If the module isn't already loaded (added) load it
-      if(!context->moduleAdded(&moduleId))
-	{
-	  rc = context->addModule(&moduleId, FALSE /*no timestamp check*/,
-				  TRUE /* unpack tdbs*/, 
-				  (modDir_[0] ? modDir_ : NULL),
-				  FALSE /*do not look in global mod dir*/);
-	}
     }
   
   // Get a pointer to the statement list for this context.

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/executor/ExExplain.h
----------------------------------------------------------------------
diff --git a/core/sql/executor/ExExplain.h b/core/sql/executor/ExExplain.h
index e9a1bae..1e27fa8 100644
--- a/core/sql/executor/ExExplain.h
+++ b/core/sql/executor/ExExplain.h
@@ -79,16 +79,16 @@ public:
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExExplainTdb()
+  ExExplainTdb()
   {}
 
-  NA_EIDPROC virtual ~ExExplainTdb()
+  virtual ~ExExplainTdb()
   {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
 private:
   // ---------------------------------------------------------------------

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/executor/ExFastTransport.cpp
----------------------------------------------------------------------
diff --git a/core/sql/executor/ExFastTransport.cpp b/core/sql/executor/ExFastTransport.cpp
index 13d6d85..c97104d 100644
--- a/core/sql/executor/ExFastTransport.cpp
+++ b/core/sql/executor/ExFastTransport.cpp
@@ -47,9 +47,7 @@
 #include <errno.h>
 #include <pthread.h>
 #include "ComSysUtils.h"
-#ifndef __EID
 #include "SequenceFileReader.h" 
-#endif
 #include  "cli_stdh.h"
 #include "ComSmallDefs.h"
 
@@ -599,10 +597,6 @@ void ExHdfsFastExtractTcb::convertSQRowToString(ULng32 nullLen,
 
 ExWorkProcRetcode ExHdfsFastExtractTcb::work()
 {
-#ifdef __EID 
-  // This class should not be instantiated in EID.
-  return WORK_BAD_ERROR;
-#else
   Lng32 retcode = 0;
   SFW_RetCode sfwRetCode = SFW_OK;
   ULng32 recSepLen = strlen(myTdb().getRecordSeparator());
@@ -1159,7 +1153,6 @@ ExWorkProcRetcode ExHdfsFastExtractTcb::work()
   } // while
 
   return WORK_OK;
-#endif
 }//ExHdfsFastExtractTcb::work()
 
 void ExHdfsFastExtractTcb::insertUpQueueEntry(ex_queue::up_status status, ComDiagsArea *diags, NABoolean popDownQueue)

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/executor/ExFastTransport.h
----------------------------------------------------------------------
diff --git a/core/sql/executor/ExFastTransport.h b/core/sql/executor/ExFastTransport.h
index 4f57a9f..7ad950e 100644
--- a/core/sql/executor/ExFastTransport.h
+++ b/core/sql/executor/ExFastTransport.h
@@ -40,14 +40,9 @@
 // -----------------------------------------------------------------------
 // Forward class declarations
 // -----------------------------------------------------------------------
-#ifndef __EID 
 class sql_buffer;
 class ExExeStmtGlobals;
 class SequenceFileWriter;
-#endif
-
-class SequenceFileWriter;
-
 
 // -----------------------------------------------------------------------
 // Classes defined in this file
@@ -108,18 +103,18 @@ public:
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExFastExtractTdb()
+  ExFastExtractTdb()
   {
   }
 
-  NA_EIDPROC virtual ~ExFastExtractTdb()
+  virtual ~ExFastExtractTdb()
   {
   }
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
   // ---------------------------------------------------------------------
   // Public accessor functions

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/executor/ExFirstN.h
----------------------------------------------------------------------
diff --git a/core/sql/executor/ExFirstN.h b/core/sql/executor/ExFirstN.h
index 007956e..a0b8106 100644
--- a/core/sql/executor/ExFirstN.h
+++ b/core/sql/executor/ExFirstN.h
@@ -66,16 +66,16 @@ public:
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExFirstNTdb()
+  ExFirstNTdb()
   {}
 
-  NA_EIDPROC virtual ~ExFirstNTdb()
+  virtual ~ExFirstNTdb()
   {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
 private:
   // ---------------------------------------------------------------------
@@ -144,29 +144,29 @@ class ExFirstNTcb : public ex_tcb
   
 public:
   // Constructor
-  NA_EIDPROC ExFirstNTcb(const ExFirstNTdb & firstn_tdb,    
+  ExFirstNTcb(const ExFirstNTdb & firstn_tdb,    
 	      const ex_tcb &    child_tcb,    // child queue pair
 	      ex_globals *glob
 	      );
   
-  NA_EIDPROC ~ExFirstNTcb();  
+  ~ExFirstNTcb();  
   
-  NA_EIDPROC short moveChildDataToParent();
+  short moveChildDataToParent();
 
-  NA_EIDPROC void freeResources();  // free resources
+  void freeResources();  // free resources
   
-  NA_EIDPROC short work();                     // when scheduled to do work
-  NA_EIDPROC virtual void registerSubtasks();  // register work procedures with scheduler
-  NA_EIDPROC short cancel();                   // for the fickle.
+  short work();                     // when scheduled to do work
+  virtual void registerSubtasks();  // register work procedures with scheduler
+  short cancel();                   // for the fickle.
 
-  NA_EIDPROC inline ExFirstNTdb & firstnTdb() const { return (ExFirstNTdb &) tdb; }
+  inline ExFirstNTdb & firstnTdb() const { return (ExFirstNTdb &) tdb; }
 
  
-  NA_EIDPROC ex_queue_pair getParentQueue() const { return qparent_;}
+  ex_queue_pair getParentQueue() const { return qparent_;}
 
 
-  NA_EIDPROC virtual Int32 numChildren() const { return 1; }   
-  NA_EIDPROC virtual const ex_tcb* getChild(Int32 /*pos*/) const { return childTcb_; }
+  virtual Int32 numChildren() const { return 1; }   
+  virtual const ex_tcb* getChild(Int32 /*pos*/) const { return childTcb_; }
 
 }; 
 
@@ -176,9 +176,9 @@ class ExFirstNPrivateState : public ex_tcb_private_state
   friend class ExFirstNTcb;
   
 public:
-  NA_EIDPROC ExFirstNPrivateState(const ExFirstNTcb * tcb); //constructor
-  NA_EIDPROC ex_tcb_private_state * allocate_new(const ex_tcb * tcb);
-  NA_EIDPROC ~ExFirstNPrivateState();       // destructor
+  ExFirstNPrivateState(const ExFirstNTcb * tcb); //constructor
+  ex_tcb_private_state * allocate_new(const ex_tcb * tcb);
+  ~ExFirstNPrivateState();       // destructor
 };
 
 #endif

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/executor/ExHbaseAccess.h
----------------------------------------------------------------------
diff --git a/core/sql/executor/ExHbaseAccess.h b/core/sql/executor/ExHbaseAccess.h
index c402eba..098d779 100644
--- a/core/sql/executor/ExHbaseAccess.h
+++ b/core/sql/executor/ExHbaseAccess.h
@@ -68,16 +68,16 @@ public:
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExHbaseAccessTdb()
+  ExHbaseAccessTdb()
   {}
 
-  NA_EIDPROC virtual ~ExHbaseAccessTdb()
+  virtual ~ExHbaseAccessTdb()
   {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
 private:
   // ---------------------------------------------------------------------
@@ -1271,16 +1271,16 @@ public:
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExHbaseCoProcAggrTdb()
+  ExHbaseCoProcAggrTdb()
   {}
 
-  NA_EIDPROC virtual ~ExHbaseCoProcAggrTdb()
+  virtual ~ExHbaseCoProcAggrTdb()
   {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
 private:
   // ---------------------------------------------------------------------

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/executor/ExHdfsScan.h
----------------------------------------------------------------------
diff --git a/core/sql/executor/ExHdfsScan.h b/core/sql/executor/ExHdfsScan.h
index 407fa48..d9ab216 100644
--- a/core/sql/executor/ExHdfsScan.h
+++ b/core/sql/executor/ExHdfsScan.h
@@ -72,16 +72,16 @@ public:
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExHdfsScanTdb()
+  ExHdfsScanTdb()
   {}
 
-  NA_EIDPROC virtual ~ExHdfsScanTdb()
+  virtual ~ExHdfsScanTdb()
   {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
 private:
   // ---------------------------------------------------------------------
@@ -374,16 +374,16 @@ public:
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExOrcFastAggrTdb()
+  ExOrcFastAggrTdb()
   {}
 
-  NA_EIDPROC virtual ~ExOrcFastAggrTdb()
+  virtual ~ExOrcFastAggrTdb()
   {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
 private:
   // ---------------------------------------------------------------------

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/executor/ExMeas.cpp
----------------------------------------------------------------------
diff --git a/core/sql/executor/ExMeas.cpp b/core/sql/executor/ExMeas.cpp
index 503968e..ade3632 100644
--- a/core/sql/executor/ExMeas.cpp
+++ b/core/sql/executor/ExMeas.cpp
@@ -20,144 +20,3 @@
 //
 // @@@ END COPYRIGHT @@@
 **********************************************************************/
-/* -*-C++-*-
- *****************************************************************************
- *
- * File:         ExMeas.cpp
- * Description:  methods for classes ExMeasStmtCntrs and ExMeasProcCntrs
- *               
- *               
- * Created:      9/26/2000
- * Language:     C++
- *
- *
- *
- *
- *****************************************************************************
- */
-
-#include "ExMeas.h"
-#include "str.h"
-#include "ComCextdecs.h"
-
-#include "dmeasql.h"
-
-
-#include "seabed/trace.h"
-
-#include "ex_ex.h"
-
-/******************************************************************/
-// class ExMeasStmtCntrs    
-/******************************************************************/
- 
-void ExMeasStmtCntrs::init(Int32 statementIndex)
-{
-#pragma nowarn(1506)   // warning elimination 
-  stmtCtrs_.statement_index = statementIndex;
-#pragma warn(1506)  // warning elimination 
-  stmtCtrs_.sorts = 0;
-  stmtCtrs_.recompiles = 0;
-  stmtCtrs_.lock_waits = 0;
-  stmtCtrs_.calls = 0;
-  stmtCtrs_.elapsed_busy_time = 0;
-  stmtCtrs_.records_accessed = 0;
-  stmtCtrs_.records_used = 0;
-  stmtCtrs_.disc_reads = 0;
-  stmtCtrs_.messages = 0;
-  stmtCtrs_.message_bytes = 0;
-  stmtCtrs_.elapsed_sort_time = 0;
-  stmtCtrs_.elapsed_compile_time = 0;
-  stmtCtrs_.timeouts = 0;
-  stmtCtrs_.escalations = 0;
-};  
-
-ExMeasStmtCntrs::ExMeasStmtCntrs()
-{
-  init(0);
-#ifdef NA_LINUX_DEBUG
-  trace_printf("ExMeasStmtCntrsBump(%p) ctor\n", this);
-#endif
-}
-
-ExMeasStmtCntrs::~ExMeasStmtCntrs()
-{
-#ifdef NA_LINUX_DEBUG
-  trace_printf("ExMeasStmtCntrsBump(%p) dtor\n", this);
-#endif
-};
-  
-// Update Measure statement counters.
-Int32 ExMeasStmtCntrs::ExMeasStmtCntrsBump(Int32 statementCount, char *moduleName, 
-					 Int32 moduleNameLen)
-{
-
-#ifdef NA_LINUX_DEBUG
-  trace_printf("ExMeasStmtCntrsBump (%p): %d %s\n", this, statementCount, moduleName);
-#endif
-  return 0;
-}
-
-
-
-
-/******************************************************************/
-// class ExMeasProcCntrs    
-/******************************************************************/
-ExMeasProcCntrs::ExMeasProcCntrs()
-{
-  procCtrs_.sql_obj_recompiles= 0;
-  procCtrs_.sql_obj_recompile_time = 0;
-  procCtrs_.sql_stmt_recompiles = 0;
-  procCtrs_.sql_stmt_recompile_time = 0;
-  procCtrs_.sql_newprocesses = 0;
-  procCtrs_.sql_newprocess_time = 0;
-  procCtrs_.opens = 0;
-  procCtrs_.open_time = 0;
-#ifdef NA_LINUX_DEBUG
-  trace_printf("ExMeasProcCntrs(%p) ctor\n", this);
-#endif
-};
-
-ExMeasProcCntrs::~ExMeasProcCntrs()
-{
-#ifdef NA_LINUX_DEBUG
-  trace_printf("ExMeasProcCntrs(%p) dtor\n", this);
-#endif
-};
-
-Int32 ExMeasProcCntrs::ExMeasProcCntrsBump ()
-{
-#ifdef NA_LINUX_DEBUG
-  trace_printf("ExMeasProcCntrsBump\n");
-#endif
-  return 0;
-}
-
-Int32 ExMeasGetStatus (NABoolean &stmtflag /* out */
-                   , NABoolean &procflag /* out */
-                   , NABoolean &measureflag /* out */)
-{
-  Int32 status = 0;
-  static short dSqlMeasureEnabled = 0;
-  static bool  bCheckedMeasureEnv = false;
-
-  if (!bCheckedMeasureEnv) {
-    const char * pEnvStr = getenv("SQL_MEASURE_ENABLE");
-    if (pEnvStr != NULL) {
-      dSqlMeasureEnabled = atoi(pEnvStr);
-    }
-    bCheckedMeasureEnv = true;
-  }
-  if (dSqlMeasureEnabled) {
-      stmtflag = 1;
-      procflag = 1;
-      measureflag = 1;
-  } else {
-      stmtflag = 0;
-      procflag = 0;
-      measureflag = 0;
-  }
-  
-  return 0;
-}

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/executor/ExMeas.h
----------------------------------------------------------------------
diff --git a/core/sql/executor/ExMeas.h b/core/sql/executor/ExMeas.h
index f035b17..ade3632 100644
--- a/core/sql/executor/ExMeas.h
+++ b/core/sql/executor/ExMeas.h
@@ -20,270 +20,3 @@
 //
 // @@@ END COPYRIGHT @@@
 **********************************************************************/
-#ifndef __EX_MEAS_H__
-#define __EX_MEAS_H__
-
-/* -*-C++-*-
- *****************************************************************************
- *
- * File:         ExMeas.h
- * Description:  
- *               
- *               
- * Created:      9/25/2000
- * Language:     C++
- *
- *
- *
- *
- *****************************************************************************
- */
-#include "Platform.h"
-
-#include "ComSizeDefs.h"
-#include "Int64.h"
-#include "BaseTypes.h"
-
-#define EXP_SHORT_OV_ADD_SETMAX( op1,  op2) 0
-#define EXP_FIXED_OV_ADD_SETMAX( op1,  op2) 0 
-
-// Define for the max Ansiname size.
-// See max Ansiname size definitions in w:/common/ComSizeDefs.h
-#define MODULE_ID_SIZE ComMAX_3_PART_EXTERNAL_UTF8_NAME_LEN_IN_BYTES
-
-// Defines for dynamic statement name
-
-#define DYNAMIC_STMT_NAME "SQLMX^EXECUTE_"
-#define DYNAMIC_STMT_NAME_SIZE 14
-
-
-/*****************************************************************/
-/* classes defined in this file                                  */
-/*****************************************************************/
-//class ExMeasStmtCntrs;
-//class ExMeasProcCntrs;
-
-/*****************************************************************/
-/* ExMeasGetStatus                                               */
-/* Function to check if measure is enabled.                      */
-/*  stmtflag is set true if statement counter is enabled,        */
-/*  procflag is set true if process counter is enabled.          */
-/*****************************************************************/
-Int32 ExMeasGetStatus (NABoolean &stmtflag /* out */
-                   , NABoolean &procflag /* out */
-                   , NABoolean &measureflag /* out */);   
-
-/******************************************************************/
-/* class ExMeasStmtCntrs                                          */
-/*                                                                */
-/* To store Measure Sqlstmt counters.                             */
-/******************************************************************/
-
-
-#include "dmeasql.h"
-
-
-class ExMeasStmtCntrs 
-{
-public:
-NA_EIDPROC
-   ExMeasStmtCntrs();
-
-NA_EIDPROC
-   ~ExMeasStmtCntrs();
-
-NA_EIDPROC
-   void init(Int32 statementIndex);
-
-NA_EIDPROC
-inline void setStatementIndex (short i) { stmtCtrs_.statement_index = i; }
-
-NA_EIDPROC
-inline void setSorts (short s) { stmtCtrs_.sorts = s; }
-
-NA_EIDPROC
-inline void setRecompiles (short c) { stmtCtrs_.recompiles = c; }
-
-NA_EIDPROC
-inline void setLockWaits (short lw) { stmtCtrs_.lock_waits = lw; }
-
-NA_EIDPROC
-inline void setCalls (Int64 c) { stmtCtrs_.calls = c; }
-
-NA_EIDPROC
-inline void setElapsedBusyTime(Int64 et) { stmtCtrs_.elapsed_busy_time = et; } 
-
-NA_EIDPROC
-inline void setRowsUsed (Int64 ru) { stmtCtrs_.records_used = ru; }
-
-NA_EIDPROC
-inline void setRowsAccessed (Int64 ra) { stmtCtrs_.records_accessed = ra; }
-
-NA_EIDPROC
-inline void setDiscReads (Int64 dr) { stmtCtrs_.disc_reads = dr; }
-
-NA_EIDPROC
-inline void setMessages (Int64 m) { stmtCtrs_.messages = m; }
-
-NA_EIDPROC
-inline void setMessageBytes (Int64 mb) { stmtCtrs_.message_bytes = mb; }
-
-NA_EIDPROC
-inline void setElapsedSortTime (Int64 st) { stmtCtrs_.elapsed_sort_time = st; }
-
-NA_EIDPROC
-inline void setElapsedCompileTime(Int64 ct) { stmtCtrs_.elapsed_compile_time = ct; }
-
-NA_EIDPROC
-inline void setTimeouts (short to) { stmtCtrs_.timeouts = to; }
-
-NA_EIDPROC
-inline void setEscalations (short e) { stmtCtrs_.escalations = e; }
-
-NA_EIDPROC
-inline void incSorts (short s) 
-  { stmtCtrs_.sorts = EXP_SHORT_OV_ADD_SETMAX (stmtCtrs_.sorts, s); }
-
-NA_EIDPROC
-inline void incRecompiles (short c) 
-  { stmtCtrs_.recompiles = EXP_SHORT_OV_ADD_SETMAX (stmtCtrs_.recompiles, c); }
-
-NA_EIDPROC
-inline void incLockWaits (short lw) 
-  { stmtCtrs_.lock_waits = EXP_SHORT_OV_ADD_SETMAX (stmtCtrs_.lock_waits, lw); }
-
-NA_EIDPROC
-inline void incCalls (Int64 c) 
-  { stmtCtrs_.calls = EXP_FIXED_OV_ADD_SETMAX (stmtCtrs_.calls,  c); }
-
-NA_EIDPROC
-inline void incElapseBusyTime(Int64 et) 
-  { stmtCtrs_.elapsed_busy_time = EXP_FIXED_OV_ADD_SETMAX (stmtCtrs_.elapsed_busy_time, et); } 
-
-NA_EIDPROC
-inline void incRowsUsed (Int64 ru) 
-  { stmtCtrs_.records_used = EXP_FIXED_OV_ADD_SETMAX (stmtCtrs_.records_used, ru); }
-
-NA_EIDPROC
-inline void incRowsAccessed (Int64 ra) 
-  { stmtCtrs_.records_accessed = EXP_FIXED_OV_ADD_SETMAX (stmtCtrs_.records_accessed, ra); }
-
-NA_EIDPROC
-inline void incDiscReads (Int64 dr) 
-  { stmtCtrs_.disc_reads = EXP_FIXED_OV_ADD_SETMAX (stmtCtrs_.disc_reads, dr); }
-
-NA_EIDPROC
-inline void incMessages (Int64 m) 
-  { stmtCtrs_.messages = EXP_FIXED_OV_ADD_SETMAX (stmtCtrs_.messages, m); }
-
-NA_EIDPROC
-inline void incMessageBytes (Int64 mb) 
-  { stmtCtrs_.message_bytes = EXP_FIXED_OV_ADD_SETMAX (stmtCtrs_.message_bytes, mb); }
-
-NA_EIDPROC
-inline void incElapsedSortTime (Int64 st) 
-  { stmtCtrs_.elapsed_sort_time = EXP_FIXED_OV_ADD_SETMAX (stmtCtrs_.elapsed_sort_time, st); }
-
-NA_EIDPROC
-inline void incElapsedCompileTime(Int64 ct) 
-  { stmtCtrs_.elapsed_compile_time = EXP_FIXED_OV_ADD_SETMAX (stmtCtrs_.elapsed_compile_time, ct); }
-
-NA_EIDPROC
-inline void incTimeouts (short to) 
-  { stmtCtrs_.timeouts = EXP_SHORT_OV_ADD_SETMAX (stmtCtrs_.timeouts, to); }
-
-NA_EIDPROC
-inline void incEscalations (short e) 
-  { stmtCtrs_.escalations = EXP_SHORT_OV_ADD_SETMAX (stmtCtrs_.escalations, e); }
-
-// Update Measure statement counters.
-NA_EIDPROC
-Int32 ExMeasStmtCntrsBump (Int32 statementCount, char *moduleName, Int32 moduleNameLen);
-
-private:
-    SQLSTMT_CTRS_DEF stmtCtrs_; 
-
-};
-
-
-/******************************************************************/
-/* class ExMeasProcCntrs                                          */
-/*                                                                */
-/* To store Measure Sqlproc counters. Should have the same layout */
-/* as the Measure SQLPROC^CTRS^DEF.                               */
-/******************************************************************/
-
-class ExMeasProcCntrs
-{
-public:
-NA_EIDPROC
-   ExMeasProcCntrs();
-
-NA_EIDPROC
-   ~ExMeasProcCntrs();
-
-NA_EIDPROC
-inline void setSqlObjRecompiles(short rc) { procCtrs_.sql_obj_recompiles = rc; }
-
-NA_EIDPROC
-inline void setSqlObjRecompileTime(Int64 rct) { procCtrs_.sql_obj_recompile_time = rct; } 
-
-NA_EIDPROC
-inline void setSqlStmtRecompiles(short rc) { procCtrs_.sql_stmt_recompiles = rc; }
-
-NA_EIDPROC
-inline void setSqlStmtRecompileTime(Int64 rct) { procCtrs_.sql_stmt_recompile_time = rct; }
-
-NA_EIDPROC
-inline void setSqlNewprocesses(short n) { procCtrs_.sql_newprocesses = n; }
-
-NA_EIDPROC
-inline void setSqlNewprocesstime(Int64 nt) { procCtrs_.sql_newprocess_time = nt; }
-
-NA_EIDPROC
-inline void setOpens (short op) { procCtrs_.opens = op; }
-
-NA_EIDPROC
-inline void setOpenTime (Int64 ot) { procCtrs_.open_time = ot; }
-
-NA_EIDPROC
-inline void incSqlObjRecompiles(short rc) 
-  { procCtrs_.sql_obj_recompiles = EXP_SHORT_OV_ADD_SETMAX (procCtrs_.sql_obj_recompiles, rc); }
-
-NA_EIDPROC
-inline void incSqlObjRecompileTime(Int64 rct) 
-  { procCtrs_.sql_obj_recompile_time = EXP_FIXED_OV_ADD_SETMAX (procCtrs_.sql_obj_recompile_time, rct ); } 
-
-NA_EIDPROC
-inline void incSqlStmtRecompiles(short rc) 
-  { procCtrs_.sql_stmt_recompiles = EXP_SHORT_OV_ADD_SETMAX (procCtrs_.sql_stmt_recompiles, rc); }
-
-NA_EIDPROC
-inline void incSqlStmtRecompileTime(Int64 rct) 
-  { procCtrs_.sql_stmt_recompile_time = EXP_FIXED_OV_ADD_SETMAX (procCtrs_.sql_stmt_recompile_time, rct ); }
-
-NA_EIDPROC
-inline void incNewprocess (short np) 
-  { procCtrs_.sql_newprocesses =  EXP_SHORT_OV_ADD_SETMAX (procCtrs_.sql_newprocesses, np ); }
-
-NA_EIDPROC
-inline void incNewprocessTime (Int64 nt) 
-  { procCtrs_.sql_newprocess_time = EXP_FIXED_OV_ADD_SETMAX (procCtrs_.sql_newprocess_time, nt); }
-
-NA_EIDPROC
-inline void incOpens (short op) 
-  { procCtrs_.opens =  EXP_SHORT_OV_ADD_SETMAX (procCtrs_.opens, op ); }
-
-NA_EIDPROC
-inline void incOpenTime (Int64 ot) { procCtrs_.open_time = procCtrs_.open_time + ot; }
-
-// Update Measure process counters.
-NA_EIDPROC
-Int32 ExMeasProcCntrsBump ();
-
-private:
-    SQLPROC_CTRS_DEF procCtrs_;
-
-};
-
-#endif

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/executor/ExPack.h
----------------------------------------------------------------------
diff --git a/core/sql/executor/ExPack.h b/core/sql/executor/ExPack.h
index 53b63ea..9b4ea93 100644
--- a/core/sql/executor/ExPack.h
+++ b/core/sql/executor/ExPack.h
@@ -71,16 +71,16 @@ public:
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExPackRowsTdb()
+  ExPackRowsTdb()
   {}
 
-  NA_EIDPROC virtual ~ExPackRowsTdb()
+  virtual ~ExPackRowsTdb()
   {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
 private:
   // ---------------------------------------------------------------------
@@ -144,43 +144,34 @@ public:
   //     - initializes local state.
   //     - fixes up all expressions.
   //
-  NA_EIDPROC
   ExPackRowsTcb(const ExPackRowsTdb& packTdb,
             const ex_tcb& childTdb,    
             ex_globals* glob);
 	  
   // Destructor
-  NA_EIDPROC
   ~ExPackRowsTcb();  
 
   // Free up any run-time resources.
-  NA_EIDPROC
   void freeResources(); 
 
   // Register all the pack subtasks with the scheduler.
-  NA_EIDPROC
   void registerSubtasks();
 
   // The basic work method for a TCB. Pack does not use this method.
-  NA_EIDPROC
   ExWorkProcRetcode work();
 
   // Work method to pass requests from parent down to child.
-  NA_EIDPROC
   ExWorkProcRetcode workDown();
 
   // Work method to recieve results from child, process and pass up to parent
   // when the packed record has been formed or there is EOD.
-  NA_EIDPROC
   ExWorkProcRetcode workUp();
 
   // Work method called by workUp() to return rows when we form a fully packed
   // record or get an EOD before that.
-  NA_EIDPROC
   ExWorkProcRetcode workReturnRow();
   
   // Stub to workUp() used by scheduler.
-  NA_EIDPROC
 // warning elimination (removed "inline")
   static ExWorkProcRetcode sWorkUp(ex_tcb *tcb)
   {
@@ -188,7 +179,6 @@ public:
   } 
   
   // Stub to workDown() used by scheduler.
-  NA_EIDPROC
 // warning elimination (removed "inline")
   static ExWorkProcRetcode sWorkDown(ex_tcb *tcb)
   {
@@ -196,7 +186,6 @@ public:
   }
   
   // Stub to processCancel() used by scheduler.
-  NA_EIDPROC
 // warning elimination (removed "inline")
   static ExWorkProcRetcode sCancel(ex_tcb *tcb)
   {
@@ -204,31 +193,25 @@ public:
   }
 
   // Return the parent queue pair.
-  NA_EIDPROC
 // warning elimination (removed "inline")
   ex_queue_pair getParentQueue() const { return qParent_; }
 
   // Return a reference to the Pack TDB associated with this Pack TCB.
-  NA_EIDPROC
   inline ExPackRowsTdb& packTdb() const
   {
     return (ExPackRowsTdb &) tdb;
   }
 
   // Return the selection predicate.
-  NA_EIDPROC
   inline ex_expr* predExpr() { return packTdb().predExpr_; }
 
   // Return the packing expression.
-  NA_EIDPROC
   inline ex_expr* packExpr() { return packTdb().packExpr_; }
 
   // Pack has one child.
-  NA_EIDPROC
   virtual Int32 numChildren() const { return 1; }   
 
   // Return the child of the pack node by position.
-  NA_EIDPROC
   virtual const ex_tcb* getChild(Int32 pos) const
   {
     if(pos == 0) return childTcb_;
@@ -253,15 +236,12 @@ protected:
   ExSimpleSQLBuffer* pool_;
 
   // Send next request down to children. (called by workDown())
-  NA_EIDPROC
   void start();
 
   // Send EOD to parent. (called when child return Q_NO_DATA in queue)
-  NA_EIDPROC
   void stop();
 
   // Process cancel requests. (called when parent cancel its request)
-  NA_EIDPROC
   ExWorkProcRetcode processCancel(); 
    
 };
@@ -277,21 +257,16 @@ class ExPackPrivateState : public ex_tcb_private_state
   ExPackRowsTcb::workState childState_;
   Int64 matchCount_; 
 
-  NA_EIDPROC
   void init();        
 
 public:
 
-  NA_EIDPROC
   ExPackPrivateState(const ExPackRowsTcb* tcb);
 
-  NA_EIDPROC
   ~ExPackPrivateState();
 
-  NA_EIDPROC
   ex_tcb_private_state* allocate_new(const ex_tcb* tcb);
 
-  NA_EIDPROC
   void printPackTupp();
 
 };

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/executor/ExPackedRows.h
----------------------------------------------------------------------
diff --git a/core/sql/executor/ExPackedRows.h b/core/sql/executor/ExPackedRows.h
index 89612db..e80a609 100644
--- a/core/sql/executor/ExPackedRows.h
+++ b/core/sql/executor/ExPackedRows.h
@@ -78,16 +78,16 @@ public:
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExUnPackRowsTdb()
+  ExUnPackRowsTdb()
   {}
 
-  NA_EIDPROC virtual ~ExUnPackRowsTdb()
+  virtual ~ExUnPackRowsTdb()
   {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
 private:
   // ---------------------------------------------------------------------
@@ -182,7 +182,6 @@ public:
   //    IN: Contains references to global executor information,
   //        notably the space object used to allocate objects.
   //
-  NA_EIDPROC
   ExUnPackRowsTcb(const ExUnPackRowsTdb &unPackTdb,
                   const ex_tcb &childTdb,    
                   ex_globals *glob);
@@ -190,7 +189,6 @@ public:
 
   // Destructor
   //
-  NA_EIDPROC
   ~ExUnPackRowsTcb();  
 
   // Free up any run-time resources.
@@ -198,35 +196,29 @@ public:
   // (Does not free up the queues, should it).
   // Called by the destructor.
   //
-  NA_EIDPROC
   void freeResources(); 
 
   // Register all the UnPackRows subtasks with the scheduler.
   //
-  NA_EIDPROC
   void registerSubtasks();
 
   // The basic work method for a TCB.  UnPackRows does not
   // use this method, but rather uses three subtasks.
   // - sWorkDown(), sWorkUp() and sCancel().
   //
-  NA_EIDPROC
   ExWorkProcRetcode work();
 
   // Work method to pass requests from parent down to child.
   //
-  NA_EIDPROC
   ExWorkProcRetcode workDown();
 
   // Work method to recieve results from child, process and
   // pass up to parent.
   //
-  NA_EIDPROC
   virtual ExWorkProcRetcode workUp();
   
   // Stub to workUp() used by scheduler.
   //
-  NA_EIDPROC
   // warning elimination (removed "inline")
   static ExWorkProcRetcode sWorkUp(ex_tcb *tcb)
   {
@@ -235,7 +227,6 @@ public:
   
   // Stub to workDown() used by scheduler.
   // 
-  NA_EIDPROC
   // warning elimination (removed "inline")
   static ExWorkProcRetcode sWorkDown(ex_tcb *tcb)
   {
@@ -244,7 +235,6 @@ public:
   
   // Stub to processCancel() used by scheduler.
   //
-  NA_EIDPROC
 // warning elimination (removed "inline")
   static ExWorkProcRetcode sCancel(ex_tcb *tcb)
   {
@@ -253,35 +243,29 @@ public:
 
   // Return the parent queue pair.
   //
-  NA_EIDPROC
 // warning elimination (removed "inline")
   ex_queue_pair getParentQueue() const { return qParent_; }
 
   // Return a reference to the UnPackRows TDB associated with this 
   // UnPackRows TCB.
   //
-  NA_EIDPROC
   inline ExUnPackRowsTdb &unPackRowsTdb() const 
   {
     return(ExUnPackRowsTdb &)tdb; 
   }
 
-  NA_EIDPROC
   inline ex_expr *packingFactor() { return unPackRowsTdb().packingFactor_; }
   
   // Return the UnPackRows expression 
   //
-  NA_EIDPROC
   inline ex_expr *unPackColsExpr() { return unPackRowsTdb().unPackColsExpr_; }
 
   // UnPackRows has one child.
   //
-  NA_EIDPROC
   virtual Int32 numChildren() const { return 1; }   
 
   // Return the child of the UnPackRows node by position.
   //
-  NA_EIDPROC
   virtual const ex_tcb * getChild(Int32 pos) const 
   {
     if(pos == 0) return childTcb_;
@@ -380,18 +364,14 @@ class ExUnPackRowsPrivateState : public ex_tcb_private_state
 
   Int32 nextCLIErrorRowNum_;
 
-  NA_EIDPROC
   void init();        
 
 public:
 
-  NA_EIDPROC
   ExUnPackRowsPrivateState(const ExUnPackRowsTcb * tcb); 
 
-  NA_EIDPROC
   ex_tcb_private_state * allocate_new(const ex_tcb * tcb);
 
-  NA_EIDPROC
   ~ExUnPackRowsPrivateState();  
 };
 
@@ -410,7 +390,6 @@ class ExUnPackRowwiseRowsTcb : public ex_tcb
 public:
 
   // Constructor
-  NA_EIDPROC
   ExUnPackRowwiseRowsTcb(const ExUnPackRowsTdb &unPackTdb,
 			 ex_globals *glob);
           

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/executor/ExProbeCache.h
----------------------------------------------------------------------
diff --git a/core/sql/executor/ExProbeCache.h b/core/sql/executor/ExProbeCache.h
index 8059daa..8ff3573 100644
--- a/core/sql/executor/ExProbeCache.h
+++ b/core/sql/executor/ExProbeCache.h
@@ -57,16 +57,16 @@ public:
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExProbeCacheTdb()
+  ExProbeCacheTdb()
   {}
 
-  NA_EIDPROC virtual ~ExProbeCacheTdb()
+  virtual ~ExProbeCacheTdb()
   {}
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
 private:
   // ---------------------------------------------------------------------
@@ -146,7 +146,7 @@ public:
     }
 
 
-  NA_EIDPROC virtual ex_tcb_private_state * allocatePstates(
+  virtual ex_tcb_private_state * allocatePstates(
        Lng32 &numElems,      // inout, desired/actual elements
        Lng32 &pstateLength); // out, length of one element
 

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/executor/ExRLE.h
----------------------------------------------------------------------
diff --git a/core/sql/executor/ExRLE.h b/core/sql/executor/ExRLE.h
index 996bd3c..4cc608d 100644
--- a/core/sql/executor/ExRLE.h
+++ b/core/sql/executor/ExRLE.h
@@ -125,26 +125,16 @@ typedef struct comp_buf {
 #define RLE_PACKBITS_MAXBUF_BYTE    (RLE_PACKBITS_MAXCOPY_BYTE + RLE_PACKBITS_MINRUN - 1)
 #define RLE_PACKBITS_MAXBUF_SHORT    (RLE_PACKBITS_MAXCOPY_SHORT + RLE_PACKBITS_MINRUN - 1)
 
-NA_EIDPROC
 static Int32 encode_byte(unsigned char *dbuf, Int32 dlen, unsigned char *ebuf, Int32 *elen);
-NA_EIDPROC
 static Int32 pb_encode_byte(unsigned char *dbuf, Int32 dlen, unsigned char *ebuf, Int32 *elen);
-NA_EIDPROC
 static Int32 encode_short(unsigned short *dbuf, Int32 dlen_bytes, unsigned short *ebuf, Int32 *elen_bytes);
-NA_EIDPROC
 static Int32 pb_encode_short(unsigned short *dbuf, Int32 dlen_bytes, unsigned short *ebuf, Int32 *elen_bytes);
-NA_EIDPROC
 static Int32 decode_byte(unsigned char *ebuf, Int32 elen, unsigned char *dbuf, Int32 *dlen);
-NA_EIDPROC
 static Int32 pb_decode_byte(unsigned char *ebuf, Int32 elen, unsigned char *dbuf, Int32 *dlen);
-NA_EIDPROC
 static Int32 decode_short(unsigned short *ebuf, Int32 elen_bytes, unsigned short *dbuf, Int32 *dlen_bytes);
-NA_EIDPROC
 static Int32 pb_decode_short(unsigned short *ebuf, Int32 elen_bytes, unsigned short *dbuf, Int32 *dlen_bytes);
 
-NA_EIDPROC
 Int32 ExEncode(unsigned char *dbuf, Int32 dlen, unsigned char *ebuf, Int32 *elen, Int32 flags);
-NA_EIDPROC
 Int32 ExDecode(unsigned char *ebuf, Int32 elen, unsigned char *dbuf, Int32 *dlen,
 	     Lng32 &param1, Lng32 &param2);
 

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/executor/ExRsInfo.cpp
----------------------------------------------------------------------
diff --git a/core/sql/executor/ExRsInfo.cpp b/core/sql/executor/ExRsInfo.cpp
index 39f2d0a..ea6873e 100644
--- a/core/sql/executor/ExRsInfo.cpp
+++ b/core/sql/executor/ExRsInfo.cpp
@@ -79,7 +79,7 @@
 #include "ex_exe_stmt_globals.h"
 #include "ExUdrClientIpc.h"
 
-#ifdef NA_DEBUG_C_RUNTIME
+#ifdef _DEBUG
 #include <stdarg.h>
 #define ExRsDebug0(s) ExRsPrintf((s))
 #define ExRsDebug1(s,a1) ExRsPrintf((s),(a1))
@@ -129,7 +129,7 @@ ExRsInfo::ExRsInfo()
     numReturnedByLastCall_(0),
     numClosedSinceLastCall_(0)
 {
-#ifdef NA_DEBUG_C_RUNTIME
+#ifdef _DEBUG
   // We enable the debug_ flag if either the UDR_DEBUG or UDR_RS_DEBUG
   // env var is set. We enable the txDebug_ flag if either debug_ is
   // enabled or the UDR_TX_DEBUG env var is set.
@@ -664,7 +664,7 @@ void ExRsInfo::setNumEntries(ComUInt32 maxEntries)
 */
 void ExRsInfo::setIpcProcessId(const IpcProcessId &ipcProcessId)
 {
-#ifdef NA_DEBUG_C_RUNTIME
+#ifdef _DEBUG
   char buf[300];
   ipcProcessId.toAscii(buf, 300);
   ExRsDebug1("[BEGIN setIpcProcessId] ipcProcessId=%s", buf);
@@ -673,7 +673,7 @@ void ExRsInfo::setIpcProcessId(const IpcProcessId &ipcProcessId)
   ExRsDebug0("[END setIpcProcessId]");
 }// ExRsInfo::setIpcProcessId
 
-#ifdef NA_DEBUG_C_RUNTIME
+#ifdef _DEBUG
 void ExRsInfo::displayList() const  
 {
   ULng32 e = getNumEntries();
@@ -723,7 +723,7 @@ void ExRsInfo::ExRsPrintf(const char *formatString, ...) const
 // encountered.
 void ExRsInfo::enterUdrTx(ExExeStmtGlobals &stmtGlobals)
 {
-#ifdef NA_DEBUG_C_RUNTIME
+#ifdef _DEBUG
   NABoolean oldDebug = debug_;
   if (txDebug_)
     debug_ = TRUE;
@@ -737,7 +737,7 @@ void ExRsInfo::enterUdrTx(ExExeStmtGlobals &stmtGlobals)
     sendTxMessage(stmtGlobals, ENTER);
   }
   
-#ifdef NA_DEBUG_C_RUNTIME
+#ifdef _DEBUG
   ExRsDebug2("[END enterUdrTx] %p, state %s",
              this, getTxStateString(txState_));
   debug_ = oldDebug;
@@ -750,7 +750,7 @@ void ExRsInfo::enterUdrTx(ExExeStmtGlobals &stmtGlobals)
 // IPC errors are encountered.
 void ExRsInfo::suspendUdrTx(ExExeStmtGlobals &stmtGlobals)
 {
-#ifdef NA_DEBUG_C_RUNTIME
+#ifdef _DEBUG
   NABoolean oldDebug = debug_;
   if (txDebug_)
     debug_ = TRUE;
@@ -764,7 +764,7 @@ void ExRsInfo::suspendUdrTx(ExExeStmtGlobals &stmtGlobals)
     sendTxMessage(stmtGlobals, SUSPEND);
   }
 
-#ifdef NA_DEBUG_C_RUNTIME
+#ifdef _DEBUG
   ExRsDebug2("[END suspendUdrTx] %p, state %s",
              this, getTxStateString(txState_));
   debug_ = oldDebug;
@@ -777,7 +777,7 @@ void ExRsInfo::suspendUdrTx(ExExeStmtGlobals &stmtGlobals)
 // encountered.
 void ExRsInfo::exitUdrTx(ExExeStmtGlobals &stmtGlobals)
 {
-#ifdef NA_DEBUG_C_RUNTIME
+#ifdef _DEBUG
   NABoolean oldDebug = debug_;
   if (txDebug_)
     debug_ = TRUE;
@@ -796,7 +796,7 @@ void ExRsInfo::exitUdrTx(ExExeStmtGlobals &stmtGlobals)
     sendTxMessage(stmtGlobals, EXIT);
   }
 
-#ifdef NA_DEBUG_C_RUNTIME
+#ifdef _DEBUG
   ExRsDebug2("[END exitUdrTx] %p, state %s",
              this, getTxStateString(txState_));
   debug_ = oldDebug;
@@ -843,7 +843,7 @@ void ExRsInfo::sendTxMessage(ExExeStmtGlobals &stmtGlobals, TxMsgType t)
   if (!(ipcProcessId_ == otherEnd) ||
       (udrServer_->getState() == ExUdrServer::EX_UDR_BROKEN))
   {
-#ifdef NA_DEBUG_C_RUNTIME
+#ifdef _DEBUG
     if (!(ipcProcessId_ == otherEnd))
     {
       char buf1[300];
@@ -958,7 +958,7 @@ void ExRsInfo::sendTxMessage(ExExeStmtGlobals &stmtGlobals, TxMsgType t)
     exitOrSuspendStream_ = s;
   }
 
-#ifdef NA_DEBUG_C_RUNTIME
+#ifdef _DEBUG
   if (debug_)
     s->setTraceFile(stdout);
 #endif

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/executor/ExRsInfo.h
----------------------------------------------------------------------
diff --git a/core/sql/executor/ExRsInfo.h b/core/sql/executor/ExRsInfo.h
index c78aeb5..5231184 100644
--- a/core/sql/executor/ExRsInfo.h
+++ b/core/sql/executor/ExRsInfo.h
@@ -233,7 +233,7 @@ private:
   ULng32 numReturnedByLastCall_;
   ULng32 numClosedSinceLastCall_;
 
-#ifdef NA_DEBUG_C_RUNTIME
+#ifdef _DEBUG
 public:
   void ExRsPrintf(const char *formatString, ...) const;
   NABoolean debugEnabled() const { return debug_; }

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/executor/ExSample.h
----------------------------------------------------------------------
diff --git a/core/sql/executor/ExSample.h b/core/sql/executor/ExSample.h
index 754e3d0..68440f9 100644
--- a/core/sql/executor/ExSample.h
+++ b/core/sql/executor/ExSample.h
@@ -70,16 +70,16 @@ public:
   // retrieval of the virtual table function pointer of the class while
   // unpacking. An empty constructor is enough.
   // ---------------------------------------------------------------------
-  NA_EIDPROC ExSampleTdb()
+  ExSampleTdb()
   {};
 
-  NA_EIDPROC virtual ~ExSampleTdb()
+  virtual ~ExSampleTdb()
   {};
 
   // ---------------------------------------------------------------------
   // Build a TCB for this TDB. Redefined in the Executor project.
   // ---------------------------------------------------------------------
-  NA_EIDPROC virtual ex_tcb *build(ex_globals *globals);
+  virtual ex_tcb *build(ex_globals *globals);
 
 private:
   // ---------------------------------------------------------------------
@@ -130,28 +130,28 @@ public:
     ExSamp_DONE
   };
   
-  NA_EIDPROC ExSampleTcb(const ExSampleTdb & sample_tdb,    
+  ExSampleTcb(const ExSampleTdb & sample_tdb,    
 			 const ex_tcb &    child_tcb,
 			 ex_globals * glob
 			 );
-  NA_EIDPROC ~ExSampleTcb();  
+  ~ExSampleTcb();  
   
-  NA_EIDPROC void freeResources();
-  NA_EIDPROC short work();
+  void freeResources();
+  short work();
   
-  NA_EIDPROC inline ExSampleTdb & myTdb() const;
-  NA_EIDPROC ex_queue_pair getParentQueue() const
+  inline ExSampleTdb & myTdb() const;
+  ex_queue_pair getParentQueue() const
   {
   return (qparent_);
   }
 
-  NA_EIDPROC inline ex_expr * initExpr() const;
-  NA_EIDPROC inline ex_expr * balanceExpr() const;
-  NA_EIDPROC inline Int32 returnFactorOffset() const;
-  NA_EIDPROC inline ex_expr * postPred() const;
+  inline ex_expr * initExpr() const;
+  inline ex_expr * balanceExpr() const;
+  inline Int32 returnFactorOffset() const;
+  inline ex_expr * postPred() const;
   
-  NA_EIDPROC virtual Int32 numChildren() const;
-  NA_EIDPROC virtual const ex_tcb* getChild(Int32 pos) const;
+  virtual Int32 numChildren() const;
+  virtual const ex_tcb* getChild(Int32 pos) const;
 
 private:
   const ex_tcb * childTcb_;
@@ -164,32 +164,32 @@ private:
 
 // ExSampleTdb inline function definitions
 //
-NA_EIDPROC inline ex_expr * ExSampleTcb::initExpr() const 
+inline ex_expr * ExSampleTcb::initExpr() const 
 { 
   return myTdb().initExpr_; 
 };
 
-NA_EIDPROC inline ex_expr * ExSampleTcb::balanceExpr() const 
+inline ex_expr * ExSampleTcb::balanceExpr() const 
 { 
   return myTdb().balanceExpr_; 
 };
 
-NA_EIDPROC inline Int32 ExSampleTcb::returnFactorOffset() const
+inline Int32 ExSampleTcb::returnFactorOffset() const
 { 
   return myTdb().returnFactorOffset_; 
 };
 
-NA_EIDPROC inline ex_expr * ExSampleTcb::postPred() const 
+inline ex_expr * ExSampleTcb::postPred() const 
 { 
   return myTdb().postPred_; 
 };
   
-NA_EIDPROC inline Int32 ExSampleTcb::numChildren() const 
+inline Int32 ExSampleTcb::numChildren() const 
 { 
   return 1; 
 }   
 
-NA_EIDPROC inline const ex_tcb* ExSampleTcb::getChild(Int32 pos) const
+inline const ex_tcb* ExSampleTcb::getChild(Int32 pos) const
 {
    ex_assert((pos >= 0), ""); 
    if (pos == 0)
@@ -198,7 +198,7 @@ NA_EIDPROC inline const ex_tcb* ExSampleTcb::getChild(Int32 pos) const
       return NULL;
 }
 
-NA_EIDPROC inline ExSampleTdb & ExSampleTcb::myTdb() const
+inline ExSampleTdb & ExSampleTcb::myTdb() const
 {
         return (ExSampleTdb &) tdb;
 };
@@ -211,9 +211,9 @@ class ExSamplePrivateState : public ex_tcb_private_state
   friend class ExSampleTcb;
 
 public:
-  NA_EIDPROC ExSamplePrivateState(const ExSampleTcb * tcb);
-  NA_EIDPROC ex_tcb_private_state * allocate_new(const ex_tcb * tcb);
-  NA_EIDPROC ~ExSamplePrivateState();
+  ExSamplePrivateState(const ExSampleTcb * tcb);
+  ex_tcb_private_state * allocate_new(const ex_tcb * tcb);
+  ~ExSamplePrivateState();
 
 private:
   ExSampleTcb::RequestState step_;

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/executor/ExScheduler.cpp
----------------------------------------------------------------------
diff --git a/core/sql/executor/ExScheduler.cpp b/core/sql/executor/ExScheduler.cpp
index f3b9893..544eba8 100644
--- a/core/sql/executor/ExScheduler.cpp
+++ b/core/sql/executor/ExScheduler.cpp
@@ -46,23 +46,11 @@
 #include "ExStats.h"
 #include "ex_error.h"
 
-#ifndef __EID
 // wait method need more include files
 #include "ex_exe_stmt_globals.h"
 #include "Ipc.h"
 #include "ex_frag_rt.h"
 #include "ex_root.h"
-#endif
-
-
-#ifdef __EID
-#if !defined(NDEBUG)
-// See test harness below
-#include "ex_eid_stmt_globals.h"
-#include "SqlSessionData.h"
-#endif
-#include "ex_dp2exe_root.h"
-#endif
 
 #include "ExCextdecs.h"
 #include "ComRtUtils.h"
@@ -98,24 +86,19 @@ ExScheduler::ExScheduler(ex_globals *glob)
      #endif
      subtaskTrace_[i].rmsTimeConsumed_ = -1;
   }
-#ifndef __EID
   exeTrace_ = 0;
-#endif
 }
 
 ExScheduler::~ExScheduler()
 {
-#ifndef __EID
   if (exeTrace_ && glob_->castToExExeStmtGlobals()->getCliGlobals())
   {
     ExeTraceInfo *ti = glob_->castToExExeStmtGlobals()->getCliGlobals()
                             ->getExeTraceInfo();
     ti->removeTrace(exeTrace_);
   }
-#endif
 }
 
-#ifndef __EID
 Int32 ExScheduler::printALiner(Int32 lineno, char *buf)
 {
   if (lineno >= NumLastCalled)
@@ -132,10 +115,6 @@ Int32 ExScheduler::printALiner(Int32 lineno, char *buf)
                  subtaskTrace_[lineno].rmsTimeConsumed_);
   return rv;
 }
-#endif // not __EID
-
-// const char * NodeTypeToString(ComTdb::ex_node_type nodeType);
-
 
 ExWorkProcRetcode ExScheduler::work(Int64 prevWaitTime)
 {
@@ -158,7 +137,6 @@ ExWorkProcRetcode ExScheduler::work(Int64 prevWaitTime)
   if (suspended_)
     return WORK_OK;
 
-#ifndef __EID
   if (exeTrace_ == 0 && glob_->castToExExeStmtGlobals()->getCliGlobals())
   {
     ExeTraceInfo *ti = glob_->castToExExeStmtGlobals()->getCliGlobals()
@@ -183,29 +161,7 @@ ExWorkProcRetcode ExScheduler::work(Int64 prevWaitTime)
       }
     }
   }
-#endif  // not __EID
-
-#ifdef __EID
-#if !defined(NDEBUG)
-  // This is for DEBUG exe-in-dp2.  Note the double negative in the test
-  // above.
-
-  // Test harness for EID loop detection -- only for EID.  Also, 
-  // only for debug to avoid a small performance penalty.
-  // Run through the subtasks and "unschedule" them all.  This
-  // should trigger the EID loop detection code.
-  if (((ExEidStmtGlobals *)glob_)->getSqlSessionData()->isEidLoopTest())
-    {
-      subtask = subtasks_;
-      while (subtask)
-        {
-          subtask->reset();
-          subtask = subtask->getNext();
-        }
-    }  
-#endif   // endif eid debug.
-#endif
-  
+
   ExOperStats *rootStats = NULL;
   ExFragRootOperStats *fragRootOperStats = NULL;
   ExMeasStats *measStats = NULL;
@@ -226,7 +182,7 @@ ExWorkProcRetcode ExScheduler::work(Int64 prevWaitTime)
     fragRootOperStats = rootStats->castToExFragRootOperStats();
     measStats = rootStats->castToExMeasStats();
   }
-#ifndef __EID
+
   ExProcessStats *processStats;
   if (fragRootOperStats != NULL)
   {
@@ -235,7 +191,6 @@ ExWorkProcRetcode ExScheduler::work(Int64 prevWaitTime)
      if (processStats != NULL)
          processStats->setRecentQid(fragRootOperStats->getQueryId());
   }     
-#endif     
 
   // ---------------------------------------------------------------------
   // Loop through all events that are managed by this scheduler
@@ -322,10 +277,6 @@ ExWorkProcRetcode ExScheduler::work(Int64 prevWaitTime)
           // taken before the subtask has returned.
           subtaskTrace_[lastCalledIdx_].lastWorkRetcode_ = 666;
 
-#ifndef __EID
-//          cout << "Calling subtask " << subtask << ", tcb " << subtask->tcb_ << ", name_ " << subtask->taskName_ << endl;
-#endif
-
 	  // Do the work
 	  //
           rc = subtask->work();
@@ -425,12 +376,7 @@ ExWorkProcRetcode ExScheduler::work(Int64 prevWaitTime)
 		    {
 		      // reset flag (may not have to but can't hurt)
 		      externalEventCompleted_ = FALSE;
-#ifdef __EID
-                      QueryIDStats qidstats;
-                      if ((maxCpuTime_ != LLONG_MAX) &&
-                          (qidstats.getProcessBusyTime() > maxCpuTime_))
-                        localRootTcb_->cpuLimitExceeded();
-#else
+
 
                       // Special case for cancel: master must check for I/O
                       // completion here.
@@ -447,7 +393,6 @@ ExWorkProcRetcode ExScheduler::work(Int64 prevWaitTime)
 
                       }
 
-#endif
 		      return rc;
 		    }
 
@@ -486,12 +431,10 @@ ExWorkProcRetcode ExScheduler::work(Int64 prevWaitTime)
 	      poolsBlocked = 0;
 	      prevPoolsBlocked = 0;
 
-#ifndef __EID
 	      // poll each active connection once for each cycle through
 	      // the scheduled subtasks
 	      glob_->castToExExeStmtGlobals()->getIpcEnvironment()->
 		getAllConnections()->waitOnAll(IpcImmediately);
-#endif
 	    }
 	  else if (poolsBlocked)
 	    {
@@ -520,25 +463,7 @@ ExWorkProcRetcode ExScheduler::work(Int64 prevWaitTime)
 	      poolsBlocked = 0;
 	      subtask = subtasks_;
           }  // if poolsBlocked
-#ifdef __EID
-          if (subtaskLoopCnt_++ == maxSubtaskLoops_)
-          {
-            QueryIDStats qidstats;
-            if ((maxCpuTime_ != LLONG_MAX) &&
-                (qidstats.getProcessBusyTime() > maxCpuTime_))
-            {
-              localRootTcb_->cpuLimitExceeded();
-
-              // reset subtask to NULL to ensure we return to the EID root
-              // operator before any scan tcb gets a chance to process
-              // the cancel.  This is needed since the scan tcb can insert
-              // Q_NO_DATA directly into the reply buffer.  We have to make
-              // sure that the root tcb inserts Q_SQLERROR first.
-              subtask = NULL;
-            }
-            subtaskLoopCnt_ = 1;
-          }
-#else
+
           if (rootStats)
           {
             if ((subtaskLoopCnt_ == maxSubtaskLoops_) ||
@@ -550,7 +475,6 @@ ExWorkProcRetcode ExScheduler::work(Int64 prevWaitTime)
             else
               subtaskLoopCnt_++;
           }
-#endif
         }  // if subtask == NULL
   } // While Loop
   // reset flag
@@ -700,7 +624,6 @@ ExExceptionSubtask * ExScheduler::addOrFindExceptionSubtask(
 
 NABoolean ExScheduler::checkSuspendAndLimit()
 {
-#ifndef __EID
   ExFragRootOperStats *fragRootStats = NULL;
   ExMeasStats *measRootStats = NULL;
   Int64 localCpuTime = 0;
@@ -743,7 +666,7 @@ NABoolean ExScheduler::checkSuspendAndLimit()
       }
     }
   }
-#endif // not EID
+
   return FALSE;
 }
 
@@ -762,12 +685,6 @@ ExOperStats * ExScheduler::getRootStats()
 void ExScheduler::setRootTcb(ex_tcb *tcb)
 { 
   localRootTcb_ = tcb; 
-#ifdef __EID
-  // In the EID, the interval to check CPU time is config'd with 
-  // QUERY_LIMIT_SQL_PROCESS_CPU_DP2_FREQ.
-  maxSubtaskLoops_ = ((ExEIDRootTcb *) localRootTcb_)->getSchLoopCnt();
-  subtaskLoopCnt_ = maxSubtaskLoops_;
-#endif
 }
 
 const char *ExWorkProcRetcodeToString(ExWorkProcRetcode r)
@@ -782,11 +699,7 @@ const char *ExWorkProcRetcodeToString(ExWorkProcRetcode r)
     case WORK_NOBODY_WORKED:         return "WORK_NOBODY_WORKED";
     case WORK_STATS_PREEMPT:         return "WORK_STATS_PREEMPT";
     case WORK_HASHJ_PREEMPT:         return "WORK_HASHJ_PREEMPT";
-#ifdef __EID
-    default: return "UNKNOWN";
-#else
     default: return ComRtGetUnknownString((Int32) r);
-#endif
   }
 }
diff --git a/core/sql/executor/ExExeUtilCommon.cpp b/core/sql/executor/ExExeUtilCommon.cpp
index 91d9da8..0bd991d 100644
--- a/core/sql/executor/ExExeUtilCommon.cpp
+++ b/core/sql/executor/ExExeUtilCommon.cpp
@@ -1278,8 +1278,8 @@ short ExExeUtilTcb::alterDDLLock(NABoolean add, char * tableName,
   ExExeStmtGlobals *exeGlob = getGlobals()->castToExExeStmtGlobals();
   ExMasterStmtGlobals *masterGlob = exeGlob->castToExMasterStmtGlobals();
 
-  AnsiOrNskName aonn(tableName);
-  aonn.convertAnsiOrNskName(FALSE);
+  AnsiName aonn(tableName);
+  aonn.convertAnsiName(FALSE);
   char * parts[4];
   Lng32 numParts;
   aonn.extractParts(numParts, parts);
@@ -1609,13 +1609,13 @@ Lng32 ExExeUtilTcb::extractParts
   Lng32 rc = 0;
 
   // We want to ignore any "." dots within a delimited
   // name.  The AnsiOrNskName object is ultimately deleted
   // in the ExExeUtilMainObjectTcb destructor.
   
   if (extractedPartsObj_)
     delete extractedPartsObj_;
 
-  extractedPartsObj_ = new (getHeap()) AnsiOrNskName(objectName);
+  extractedPartsObj_ = new (getHeap()) AnsiName(objectName);
   if ((rc = extractedPartsObj_->extractParts(numParts, parts)) != 0 ||
       (numParts != 3))
     {
@@ -1795,7 +1795,7 @@ Lng32 ExExeUtilTcb::extractParts
     strcpy(parts2, parts[2]);
   }
 
   /* The AnsiOrNskName() method strips out the leading
      and ending double quotes.  The following code
      is no longer needed.
 

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/1522c8cd/core/sql/executor/ExExeUtilGetStats.cpp
----------------------------------------------------------------------
@@ -1609,13 +1609,13 @@ Lng32 ExExeUtilTcb::extractParts
 
   // We want to ignore any "." dots within a delimited
-  // name.  The AnsiOrNskName object is ultimately deleted
+  // name.  The AnsiName object is ultimately deleted
   // in the ExExeUtilMainObjectTcb destructor.
   
@@ -1795,7 +1795,7 @@ Lng32 ExExeUtilTcb::extractParts
   }
 
-  /* The AnsiOrNskName() method strips out the leading
+  /* The AnsiName() method strips out the leading
      and ending double quotes.  The following code
      is no longer needed.